@@ -30,7 +30,7 @@
 #define GNOME_DESKTOP_USE_UNSTABLE_API 1
 #include <libgnome-desktop/gnome-desktop-thumbnail.h>
 
-#define DEFAULT_MAX_THREADS   5
+#define DEFAULT_MAX_THREADS   1
 #define THUMB_SEARCH_SIZE     256
 #define THUMB_SEARCH_HEIGHT   (THUMB_SEARCH_SIZE / 4 * 3)
 
@@ -296,7 +296,7 @@ totem_grilo_get_thumbnail (GObject             *object,
 
 	file = g_file_new_for_uri (url_thumb);
 	g_task_set_task_data (task, file, g_object_unref);
-	g_file_read_async (file, G_PRIORITY_DEFAULT, NULL,
+	g_file_read_async (file, G_PRIORITY_DEFAULT, cancellable,
 			   get_stream_thumbnail_cb, task);
 }
 
